Documentation
¶
Overview ¶
Package union provides union type analysis operations.
These operations extract and merge information from union types, commonly used in contextual typing and function signature merging.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DistributeExpected ¶
DistributeExpected distributes an expected return type over union members.
func FieldTypes ¶
FieldTypes collects field types from all union members that have the field.
func FunctionTypes ¶
FunctionTypes extracts function types from a union for contextual typing.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.